<?php

namespace Ems\Services;

use Doctrine\ORM\EntityManager;

use Util\Environment;
use Util\DateUtil;
use Util\NovoCodigo;

use Ems\Repository\AlteSalarioRepository;
use Ems\Util\{ Utilities, ArrayUtil };

class AlteSalarioService {
    /** @var Environment */
    protected $environment;

    /** @var AlteSalarioRepository */
    protected $alteSalarioRepository;

    public function __construct(
        AlteSalarioRepository $alteSalarioRepository,
        Environment $environment
    ) {
        $this->alteSalarioRepository         = $alteSalarioRepository;
        $this->environment                  = $environment;
    }



    public function getModalidadeSalarial() {
        $nrorg = $this->environment->getNrorg();
        return $this->alteSalarioRepository->getModalidadeSalarial($nrorg);
    }
    
    public function getTipoAlteraSal() {
        $nrorg = $this->environment->getNrorg();
        return $this->alteSalarioRepository->getTipoAlteraSal($nrorg);
    }
    
    public function getUltimoSalario($nrvinculom) {
        $nrorg = $this->environment->getNrorg();
        list ($dia, $mes, $ano) = explode ('/', date("d/m/Y"));
        $dtmescompetenc = "01/".$mes."/".$ano;
        return $this->alteSalarioRepository->getUltimoSalario($nrorg,$dtmescompetenc,$nrvinculom);
    }

    public function setAlteSalario(
        array $row
    ): int {
        $nrOrg = (int) $this->environment->getNrOrg();
        $cdOperador = (string) $this->environment->getCdOperador();
        $params = [];

        $params['NRALTESALARIO'] =
            $row['NRALTESALARIO'] ??
            NovoCodigo::geraCodigo($nrOrg, 'GPE_ALTESALARIO', 1, 12, true, false);

        $params['NRORG']                = $row['NRORG'] ?? $nrOrg;
        $params['NRVINCULOM']           = (int) $row['NRVINCULOM'];
        $params['DTALTESALARIO']        = (string) $row['DTALTESALARIO'];
        $params['NROCORRENCIA']         = (int) $row['NROCORRENCIA'];
        $params['NRTIPOALTERA']         = (int) $row['NRTIPOALTERA'];
        $params['VRSALARIO']            = $row['VRSALARIO'] ?? null;
        $params['VRPERCALTERA']         = $row['VRPERCALTERA'] ?? null;
        $params['VRPERCREAL']           = $row['VRPERCREAL'] ?? null;
        $params['VRDIFERENCAREAL']      = $row['VRDIFERENCAREAL'] ?? null;
        $params['DTINCLUSAO']           = $row['DTINCLUSAO'] ?? date('d/m/Y');
        $params['DTULTATU']             = $row['DTULTATU'] ?? null;
        $params['NRORGINCLUSAO']        = $row['NRORGINCLUSAO'] ?? $nrOrg;
        $params['CDOPERINCLUSAO']       = $row['CDOPERINCLUSAO'] ?? $cdOperador;
        $params['NRORGULTATU']          = $row['NRORGULTATU'] ?? null;
        $params['CDOPERULTATU']         = $row['CDOPERULTATU'] ?? null;
        $params['DSOBSERVACAO']         = $row['DSOBSERVACAO'] ?? null;
        $params['NRTPMODALIDSAL']       = $row['NRTPMODALIDSAL'] ?? null;
        $params['IDTPSALARIO']          = $row['IDTPSALARIO'] ?? null;
        $params['DSVALSALARIOEXTENSO']  = $row['DSVALSALARIOEXTENSO'] ?? null;
        $params['DTBASEDISSIDIO']       = $row['DTBASEDISSIDIO'] ?? null;

        $this->alteSalarioRepository->setAlteSalario($params);

        return $params['NRALTESALARIO'];
    }
}
